==> meteor-react-materializecss-1.0.24.tgz: package/src/components/datatable/TableHeader.jsx <==
import React from 'react';
import {SORT_ASC, SORT_DESC} from "./DataTable";

/**
 *
 * @param headers
 * @param sort
 * @param onSort
 * @returns {JSX.Element}
 * @constructor
 *
 * example headers={[
 *     ...
 *     {
 *           field: 'profile.branch',
 *           name: 'Branch',
 *           sortable: true,
 *           hide: !showBranch
 *      },
 *      ...
 * ]}
 */
const TableHeader = ({headers, sort, onSort}) => {

    const sortField = sort?.field || '';
    const sortOrder = sort?.order === SORT_DESC ? SORT_DESC : SORT_ASC;

    const onSortChange = (header) => {
        if (header.sortable) {
            onSort(header.field);
        }
    };

    const renderSortIcon = (header) => {
        if (header.field === 'action' || !header.sortable) {
            return <React.Fragment> </React.Fragment>;
        }
        if (sortField && sortField === header.field) {
            return sortOrder === SORT_ASC
                ? <i className={"fa fa-sort-up"} style={{color: 'red'}}></i>
                : <i className={"fa fa-sort-down"} style={{color: 'red'}}></i>
        }
        return <i className={"fa fa-sort"} style={{color: 'black'}}></i>
    };

    return (
        <thead>
        <tr>
            {headers.filter(header => !header.hide).map((header, index) => {
                const style = header.style ? header.style : {};
                style.whiteSpace = 'nowrap';
                if (header.width) {
                    style.minWidth = `${header.width}px`;
                }
                return header.field === 'action'
                    ? (<th
                        key={header.field + index}
                        colSpan={header.colspan || 1}
                        title={header.title || ''}
                    >&nbsp;</th>)
                    : (
                        <th key={(header.field || '') + index}
                            onClick={() => onSortChange(header)}
                            style={style}
                            colSpan={header.colspan || 1}
                            title={header.title || ''}
                            className={header.className || ''}
                        >
                            {renderSortIcon(header)}
                            &nbsp;
                            {header.name}
                        </th>
                    );
            })}
        </tr>
        </thead>
    );
}

export default TableHeader;

==> meteor-react-materializecss-1.0.27.tgz: package/src/components/datatable/TableHeader.jsx <==
import React from 'react';
import {SORT_ASC, SORT_DESC} from "./DataTable";

/**
 *
 * @param headers
 * @param sort
 * @param onSort
 * @returns {JSX.Element}
 * @constructor
 *
 * example headers={[
 *     ...
 *     {
 *           field: 'profile.branch',
 *           name: 'Branch',
 *           sortable: true,
 *           hide: !showBranch
 *      },
 *      ...
 * ]}
 */
const TableHeader = ({
    headers, //header option s from datatable
    columns, //visible columns object {...field: true|false, ...}
    sort, //string field 
    onSort, //event if clicked on sort icon
}) => {

    const sortField = sort?.field || '';
    const sortOrder = sort?.order === SORT_DESC ? SORT_DESC : SORT_ASC;

    const onSortChange = (header) => {
        if (header.sortable) {
            onSort(header.field);
        }
    };

    const renderSortIcon = (header) => {
        if (header.field === 'action' || !header.sortable) {
            return <React.Fragment> </React.Fragment>;
        }
        if (sortField && sortField === header.field) {
            return sortOrder === SORT_ASC
                ? <i className={"fa fa-sort-up"} style={{color: 'red'}}></i>
                : <i className={"fa fa-sort-down"} style={{color: 'red'}}></i>
        }
        return <i className={"fa fa-sort"} style={{color: 'black'}}></i>
    };

    return (
        <thead>
        <tr>
            {headers.filter(header => header.field === 'action' || columns[header.field]).map((header, index) => {
                const style = header.style ? header.style : {};
                style.whiteSpace = 'nowrap';
                if (header.width) {
                    style.width = `${header.width}px`;
                }
                return header.field === 'action'
                    ? (<th
                        key={header.field + index}
                        colSpan={header.colspan || 1}
                        title={header.title || ''}
                        style={{width: '50px'}}
                    >&nbsp;</th>)
                    : (
                        <th key={(header.field || '') + index}
                            onClick={() => onSortChange(header)}
                            style={style}
                            colSpan={header.colspan || 1}
                            title={header.title || ''}
                            className={header.className || ''}
                        >
                            {renderSortIcon(header)}
                            &nbsp;
                            {header.name}
                        </th>
                    );
            })}
        </tr>
        </thead>
    );
}

export default TableHeader;
